==> financial-settlement-metadata-0.0.838-sources.jar: com/xforceplus/ultraman/app/financialsettlement/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.financialsettlement.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2022-05-23
 */

public class PageMeta {
    public interface Charge {
        static String code() {
            return "charge";
        }
        static String name() {
            return "计费";
        }
    }
    public interface IncomeDetail {
        static String code() {
            return "incomeDetail";
        }
        static String name() {
            return "收入明细表(废弃)";
        }
    }
    public interface InvoiceManager {
        static String code() {
            return "invoiceManager";
        }
        static String name() {
            return "发票管理（废弃）";
        }
    }
    public interface ServiceCost {
        static String code() {
            return "serviceCost";
        }
        static String name() {
            return "成本";
        }
    }
    public interface ChageCodeMaintain {
        static String code() {
            return "chageCodeMaintain";
        }
        static String name() {
            return "成本编码维护";
        }
    }
    public interface DivideRule {
        static String code() {
            return "divideRule";
        }
        static String name() {
            return "规则";
        }
    }
    public interface ChargeCodebasic {
        static String code() {
            return "chargeCodebasic";
        }
        static String name() {
            return "成本编码基础信息";
        }
    }
    public interface MiddleGroundDivide {
        static String code() {
            return "middleGroundDivide";
        }
        static String name() {
            return "分摊履历";
        }
    }
    public interface ProjectBasicInfo {
        static String code() {
            return "projectBasicInfo";
        }
        static String name() {
            return "基础信息表";
        }
    }
    public interface ChargeCost {
        static String code() {
            return "chargeCost";
        }
        static String name() {
            return "成本表（废弃）";
        }
    }
    public interface ReconcilationData {
        static String code() {
            return "reconcilationData";
        }
        static String name() {
            return "核算数据(废除)";
        }
    }
    public interface Income {
        static String code() {
            return "income";
        }
        static String name() {
            return "收入页面";
        }
    }
    public interface 结算统计表 {
        static String code() {
            return "结算统计表";
        }
        static String name() {
            return "结算统计表(废弃)";
        }
    }
    public interface 定时任务列表 {
        static String code() {
            return "定时任务列表";
        }
        static String name() {
            return "定时任务列表(废弃)";
        }
    }
    public interface AccountingData {
        static String code() {
            return "accountingData";
        }
        static String name() {
            return "核算数据";
        }
    }
    public interface SettlementStatistics {
        static String code() {
            return "settlementStatistics";
        }
        static String name() {
            return "结算统计表";
        }
    }
    public interface CronJob {
        static String code() {
            return "cronJob";
        }
        static String name() {
            return "定时任务列表";
        }
    }
    public interface Contract {
        static String code() {
            return "contract";
        }
        static String name() {
            return "合同";
        }
    }
    public interface ChargeCode {
        static String code() {
            return "chargeCode";
        }
        static String name() {
            return "chargeCode(废除)";
        }
    }
    public interface ChargeCodeData {
        static String code() {
            return "chargeCodeData";
        }
        static String name() {
            return "chargeCode(废除)";
        }
    }
    public interface ChargeCodePage {
        static String code() {
            return "chargeCodePage";
        }
        static String name() {
            return "chargeCode表";
        }
    }
    public interface PayWater {
        static String code() {
            return "payWater";
        }
        static String name() {
            return "支付流水";
        }
    }
    public interface Invoice {
        static String code() {
            return "invoice";
        }
        static String name() {
            return "发票主数据";
        }
    }
    public interface RecordTable {
        static String code() {
            return "recordTable";
        }
        static String name() {
            return "记录表";
        }
    }
    public interface ContractOriginalData {
        static String code() {
            return "contractOriginalData";
        }
        static String name() {
            return "合同裸数据";
        }
    }
    public interface Order {
        static String code() {
            return "order";
        }
        static String name() {
            return "订单";
        }
    }
    public interface ChargeCodeList {
        static String code() {
            return "chargeCodeList";
        }
        static String name() {
            return "ChargeCode管理页面";
        }
    }
    public interface AllRelationships {
        static String code() {
            return "allRelationships";
        }
        static String name() {
            return "综合关系";
        }
    }
    public interface ReturnMoney {
        static String code() {
            return "returnMoney";
        }
        static String name() {
            return "回款";
        }
    }
    public interface MemberList {
        static String code() {
            return "memberList";
        }
        static String name() {
            return "人员信息列表";
        }
    }
    public interface InvoiceRawDataList {
        static String code() {
            return "invoiceRawDataList";
        }
        static String name() {
            return "发票裸数据";
        }
    }
    public interface ReceivedPaymentsNotTaken {
        static String code() {
            return "receivedPaymentsNotTaken";
        }
        static String name() {
            return "回款-未认领";
        }
    }
    public interface ReceivedPaymentsTaken {
        static String code() {
            return "receivedPaymentsTaken";
        }
        static String name() {
            return "回款-已认领";
        }
    }
    public interface ReceivedPaymentsNoNeed {
        static String code() {
            return "receivedPaymentsNoNeed";
        }
        static String name() {
            return "回款-无需认领";
        }
    }
    public interface AllocationByOrder {
        static String code() {
            return "allocationByOrder";
        }
        static String name() {
            return "按订单分配";
        }
    }
    public interface AllocationByInvoice {
        static String code() {
            return "allocationByInvoice";
        }
        static String name() {
            return "按发票分配";
        }
    }
    public interface AllocationByTaxNo {
        static String code() {
            return "allocationByTaxNo";
        }
        static String name() {
            return "按税号分配";
        }
    }
    public interface NoNeedList {
        static String code() {
            return "noNeedList";
        }
        static String name() {
            return "无需认领清单";
        }
    }
    public interface CapitalFlow {
        static String code() {
            return "capitalFlow";
        }
        static String name() {
            return "回款认领";
        }
    }
    public interface Test {
        static String code() {
            return "test";
        }
        static String name() {
            return "测试页面";
        }
    }
    public interface Record {
        static String code() {
            return "record";
        }
        static String name() {
            return "履历";
        }
    }
    public interface SettleStaticsOrderRel {
        static String code() {
            return "settleStaticsOrderRel";
        }
        static String name() {
            return "结算统计订单关系";
        }
    }
    public interface ContractTaxNo {
        static String code() {
            return "contractTaxNo";
        }
        static String name() {
            return "合同税号清单";
        }
    }
    public interface ChargeCodeBudget {
        static String code() {
            return "chargeCodeBudget";
        }
        static String name() {
            return "chargeCode预算";
        }
    }
    public interface Organize {
        static String code() {
            return "organize";
        }
        static String name() {
            return "组织信息";
        }
    }
    public interface PmsMateData {
        static String code() {
            return "pmsMateData";
        }
        static String name() {
            return "pmsMateData页面";
        }
    }
    public interface FinancialConfig {
        static String code() {
            return "financialConfig";
        }
        static String name() {
            return "财务系统配置页面-作废";
        }
    }
    public interface SyncWindowPage {
        static String code() {
            return "syncWindowPage";
        }
        static String name() {
            return "财务同步窗口-作废";
        }
    }
    public interface FinancialSyncWindow {
        static String code() {
            return "financialSyncWindow";
        }
        static String name() {
            return "财务数据同步窗口";
        }
    }
    public interface ChargeCodePrimeCostPage {
        static String code() {
            return "chargeCodePrimeCostPage";
        }
        static String name() {
            return "charegecode成本汇总页面";
        }
    }
    public interface ReconciliationDetail {
        static String code() {
            return "reconciliationDetail";
        }
        static String name() {
            return "结算对账单明细";
        }
    }
    public interface OrderTaxRelation {
        static String code() {
            return "orderTaxRelation";
        }
        static String name() {
            return "订单税号关系表";
        }
    }
    public interface OrderBillRelation {
        static String code() {
            return "orderBillRelation";
        }
        static String name() {
            return "订单结算单关系表";
        }
    }
    public interface OrderInvoiceRelation {
        static String code() {
            return "orderInvoiceRelation";
        }
        static String name() {
            return "订单发票关系表";
        }
    }
    public interface OrderInfo {
        static String code() {
            return "orderInfo";
        }
        static String name() {
            return "订单信息表";
        }
    }
    public interface Bill {
        static String code() {
            return "bill";
        }
        static String name() {
            return "结算单表";
        }
    }
    public interface BillDetail {
        static String code() {
            return "billDetail";
        }
        static String name() {
            return "结算单明细表";
        }
    }
    public interface IncomeSummary {
        static String code() {
            return "incomeSummary";
        }
        static String name() {
            return "收入表";
        }
    }
    public interface IncomeItem {
        static String code() {
            return "incomeItem";
        }
        static String name() {
            return "收入明细表";
        }
    }
    public interface ImportBatchClaimData {
        static String code() {
            return "importBatchClaimData";
        }
        static String name() {
            return "批量认领数据";
        }
    }
    public interface ChargeMetadata {
        static String code() {
            return "chargeMetadata";
        }
        static String name() {
            return "计费月流水-作废";
        }
    }
    public interface Basis {
        static String code() {
            return "basis";
        }
        static String name() {
            return "基础数据";
        }
    }
    public interface RawData {
        static String code() {
            return "rawData";
        }
        static String name() {
            return "裸数据";
        }
    }
    public interface ChargeMonthdata {
        static String code() {
            return "chargeMonthdata";
        }
        static String name() {
            return "计费月流水";
        }
    }
    public interface BillDetailMonth {
        static String code() {
            return "billDetailMonth";
        }
        static String name() {
            return "结算单用量月汇总";
        }
    }
    public interface TaxProductView {
        static String code() {
            return "taxProductView";
        }
        static String name() {
            return "税号产品绑定关系";
        }
    }
    public interface StandingBook {
        static String code() {
            return "standingBook";
        }
        static String name() {
            return "台账管理";
        }
    }
    public interface BugetItems {
        static String code() {
            return "bugetItems";
        }
        static String name() {
            return "预算科目管理";
        }
    }
    public interface ChargeCodeBudgetUsage {
        static String code() {
            return "chargeCodeBudgetUsage";
        }
        static String name() {
            return "预算使用情况页面";
        }
    }
    public interface ChargeCodeBudgetPackge {
        static String code() {
            return "chargeCodeBudgetPackge";
        }
        static String name() {
            return "预算包管理";
        }
    }
    public interface OrderReceptionInfo {
        static String code() {
            return "orderReceptionInfo";
        }
        static String name() {
            return "订单验收信息";
        }
    }
    public interface TaxNolistView {
        static String code() {
            return "taxNolistView";
        }
        static String name() {
            return "税号清单";
        }
    }
    public interface ViewContractTaxNolist {
        static String code() {
            return "viewContractTaxNolist";
        }
        static String name() {
            return "合同下的税号清单";
        }
    }
    public interface FinBill {
        static String code() {
            return "finBill";
        }
        static String name() {
            return "财务单据信息";
        }
    }
}

==> financial-settlement-metadata-0.1.23-sources.jar: com/xforceplus/ultraman/app/financialsettlement/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.financialsettlement.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2022-06-22
 */

public class PageMeta {
    public interface Charge {
        static String code() {
            return "charge";
        }
        static String name() {
            return "计费";
        }
    }
    public interface IncomeDetail {
        static String code() {
            return "incomeDetail";
        }
        static String name() {
            return "收入明细表(废弃)";
        }
    }
    public interface InvoiceManager {
        static String code() {
            return "invoiceManager";
        }
        static String name() {
            return "发票管理（废弃）";
        }
    }
    public interface ServiceCost {
        static String code() {
            return "serviceCost";
        }
        static String name() {
            return "成本";
        }
    }
    public interface ChageCodeMaintain {
        static String code() {
            return "chageCodeMaintain";
        }
        static String name() {
            return "成本编码维护";
        }
    }
    public interface DivideRule {
        static String code() {
            return "divideRule";
        }
        static String name() {
            return "规则";
        }
    }
    public interface ChargeCodebasic {
        static String code() {
            return "chargeCodebasic";
        }
        static String name() {
            return "成本编码基础信息";
        }
    }
    public interface MiddleGroundDivide {
        static String code() {
            return "middleGroundDivide";
        }
        static String name() {
            return "分摊履历";
        }
    }
    public interface ProjectBasicInfo {
        static String code() {
            return "projectBasicInfo";
        }
        static String name() {
            return "基础信息表";
        }
    }
    public interface ChargeCost {
        static String code() {
            return "chargeCost";
        }
        static String name() {
            return "成本表（废弃）";
        }
    }
    public interface ReconcilationData {
        static String code() {
            return "reconcilationData";
        }
        static String name() {
            return "核算数据(废除)";
        }
    }
    public interface Income {
        static String code() {
            return "income";
        }
        static String name() {
            return "收入页面";
        }
    }
    public interface 结算统计表 {
        static String code() {
            return "结算统计表";
        }
        static String name() {
            return "结算统计表(废弃)";
        }
    }
    public interface 定时任务列表 {
        static String code() {
            return "定时任务列表";
        }
        static String name() {
            return "定时任务列表(废弃)";
        }
    }
    public interface AccountingData {
        static String code() {
            return "accountingData";
        }
        static String name() {
            return "核算数据";
        }
    }
    public interface SettlementStatistics {
        static String code() {
            return "settlementStatistics";
        }
        static String name() {
            return "结算统计表";
        }
    }
    public interface CronJob {
        static String code() {
            return "cronJob";
        }
        static String name() {
            return "定时任务列表";
        }
    }
    public interface Contract {
        static String code() {
            return "contract";
        }
        static String name() {
            return "合同";
        }
    }
    public interface ChargeCode {
        static String code() {
            return "chargeCode";
        }
        static String name() {
            return "chargeCode(废除)";
        }
    }
    public interface ChargeCodeData {
        static String code() {
            return "chargeCodeData";
        }
        static String name() {
            return "chargeCode(废除)";
        }
    }
    public interface ChargeCodePage {
        static String code() {
            return "chargeCodePage";
        }
        static String name() {
            return "chargeCode表";
        }
    }
    public interface PayWater {
        static String code() {
            return "payWater";
        }
        static String name() {
            return "支付流水";
        }
    }
    public interface Invoice {
        static String code() {
            return "invoice";
        }
        static String name() {
            return "发票主数据";
        }
    }
    public interface RecordTable {
        static String code() {
            return "recordTable";
        }
        static String name() {
            return "记录表";
        }
    }
    public interface ContractOriginalData {
        static String code() {
            return "contractOriginalData";
        }
        static String name() {
            return "合同裸数据";
        }
    }
    public interface Order {
        static String code() {
            return "order";
        }
        static String name() {
            return "订单";
        }
    }
    public interface ChargeCodeList {
        static String code() {
            return "chargeCodeList";
        }
        static String name() {
            return "ChargeCode管理页面";
        }
    }
    public interface AllRelationships {
        static String code() {
            return "allRelationships";
        }
        static String name() {
            return "综合关系";
        }
    }
    public interface ReturnMoney {
        static String code() {
            return "returnMoney";
        }
        static String name() {
            return "回款";
        }
    }
    public interface MemberList {
        static String code() {
            return "memberList";
        }
        static String name() {
            return "人员信息列表";
        }
    }
    public interface InvoiceRawDataList {
        static String code() {
            return "invoiceRawDataList";
        }
        static String name() {
            return "发票裸数据";
        }
    }
    public interface ReceivedPaymentsNotTaken {
        static String code() {
            return "receivedPaymentsNotTaken";
        }
        static String name() {
            return "回款-未认领";
        }
    }
    public interface ReceivedPaymentsTaken {
        static String code() {
            return "receivedPaymentsTaken";
        }
        static String name() {
            return "回款-已认领";
        }
    }
    public interface ReceivedPaymentsNoNeed {
        static String code() {
            return "receivedPaymentsNoNeed";
        }
        static String name() {
            return "回款-无需认领";
        }
    }
    public interface AllocationByOrder {
        static String code() {
            return "allocationByOrder";
        }
        static String name() {
            return "按订单分配";
        }
    }
    public interface AllocationByInvoice {
        static String code() {
            return "allocationByInvoice";
        }
        static String name() {
            return "按发票分配";
        }
    }
    public interface AllocationByTaxNo {
        static String code() {
            return "allocationByTaxNo";
        }
        static String name() {
            return "按税号分配";
        }
    }
    public interface NoNeedList {
        static String code() {
            return "noNeedList";
        }
        static String name() {
            return "无需认领清单";
        }
    }
    public interface CapitalFlow {
        static String code() {
            return "capitalFlow";
        }
        static String name() {
            return "回款认领";
        }
    }
    public interface Test {
        static String code() {
            return "test";
        }
        static String name() {
            return "测试页面";
        }
    }
    public interface Record {
        static String code() {
            return "record";
        }
        static String name() {
            return "履历";
        }
    }
    public interface SettleStaticsOrderRel {
        static String code() {
            return "settleStaticsOrderRel";
        }
        static String name() {
            return "结算统计订单关系";
        }
    }
    public interface ContractTaxNo {
        static String code() {
            return "contractTaxNo";
        }
        static String name() {
            return "合同税号清单";
        }
    }
    public interface ChargeCodeBudget {
        static String code() {
            return "chargeCodeBudget";
        }
        static String name() {
            return "chargeCode预算";
        }
    }
    public interface Organize {
        static String code() {
            return "organize";
        }
        static String name() {
            return "组织信息";
        }
    }
    public interface PmsMateData {
        static String code() {
            return "pmsMateData";
        }
        static String name() {
            return "pmsMateData页面";
        }
    }
    public interface FinancialConfig {
        static String code() {
            return "financialConfig";
        }
        static String name() {
            return "财务系统配置页面-作废";
        }
    }
    public interface SyncWindowPage {
        static String code() {
            return "syncWindowPage";
        }
        static String name() {
            return "财务同步窗口-作废";
        }
    }
    public interface FinancialSyncWindow {
        static String code() {
            return "financialSyncWindow";
        }
        static String name() {
            return "财务数据同步窗口";
        }
    }
    public interface ChargeCodePrimeCostPage {
        static String code() {
            return "chargeCodePrimeCostPage";
        }
        static String name() {
            return "charegecode成本汇总页面";
        }
    }
    public interface ReconciliationDetail {
        static String code() {
            return "reconciliationDetail";
        }
        static String name() {
            return "结算对账单明细";
        }
    }
    public interface OrderTaxRelation {
        static String code() {
            return "orderTaxRelation";
        }
        static String name() {
            return "订单税号关系表";
        }
    }
    public interface OrderBillRelation {
        static String code() {
            return "orderBillRelation";
        }
        static String name() {
            return "订单结算单关系表";
        }
    }
    public interface OrderInvoiceRelation {
        static String code() {
            return "orderInvoiceRelation";
        }
        static String name() {
            return "订单发票关系表";
        }
    }
    public interface OrderInfo {
        static String code() {
            return "orderInfo";
        }
        static String name() {
            return "订单信息表";
        }
    }
    public interface Bill {
        static String code() {
            return "bill";
        }
        static String name() {
            return "结算单表";
        }
    }
    public interface BillDetail {
        static String code() {
            return "billDetail";
        }
        static String name() {
            return "结算单明细表";
        }
    }
    public interface IncomeSummary {
        static String code() {
            return "incomeSummary";
        }
        static String name() {
            return "收入表";
        }
    }
    public interface IncomeItem {
        static String code() {
            return "incomeItem";
        }
        static String name() {
            return "收入明细表";
        }
    }
    public interface ImportBatchClaimData {
        static String code() {
            return "importBatchClaimData";
        }
        static String name() {
            return "批量认领数据";
        }
    }
    public interface ChargeMetadata {
        static String code() {
            return "chargeMetadata";
        }
        static String name() {
            return "计费月流水-作废";
        }
    }
    public interface Basis {
        static String code() {
            return "basis";
        }
        static String name() {
            return "基础数据";
        }
    }
    public interface RawData {
        static String code() {
            return "rawData";
        }
        static String name() {
            return "裸数据";
        }
    }
    public interface ChargeMonthdata {
        static String code() {
            return "chargeMonthdata";
        }
        static String name() {
            return "计费月流水";
        }
    }
    public interface BillDetailMonth {
        static String code() {
            return "billDetailMonth";
        }
        static String name() {
            return "结算单用量月汇总";
        }
    }
    public interface TaxProductView {
        static String code() {
            return "taxProductView";
        }
        static String name() {
            return "税号产品绑定关系";
        }
    }
    public interface StandingBook {
        static String code() {
            return "standingBook";
        }
        static String name() {
            return "台账管理";
        }
    }
    public interface BugetItems {
        static String code() {
            return "bugetItems";
        }
        static String name() {
            return "预算科目管理";
        }
    }
    public interface ChargeCodeBudgetUsage {
        static String code() {
            return "chargeCodeBudgetUsage";
        }
        static String name() {
            return "预算使用情况页面";
        }
    }
    public interface ChargeCodeBudgetPackge {
        static String code() {
            return "chargeCodeBudgetPackge";
        }
        static String name() {
            return "预算包管理";
        }
    }
    public interface OrderReceptionInfo {
        static String code() {
            return "orderReceptionInfo";
        }
        static String name() {
            return "订单验收信息";
        }
    }
    public interface TaxNolistView {
        static String code() {
            return "taxNolistView";
        }
        static String name() {
            return "税号清单";
        }
    }
    public interface ViewContractTaxNolist {
        static String code() {
            return "viewContractTaxNolist";
        }
        static String name() {
            return "合同下的税号清单";
        }
    }
    public interface FinBill {
        static String code() {
            return "finBill";
        }
        static String name() {
            return "财务单据信息";
        }
    }
    public interface BillSyn {
        static String code() {
            return "billSyn";
        }
        static String name() {
            return "单据同步";
        }
    }
    public interface ProjectInfoUnderContract {
        static String code() {
            return "projectInfoUnderContract";
        }
        static String name() {
            return "项目基础信息";
        }
    }
    public interface KamStandingBook {
        static String code() {
            return "kamStandingBook";
        }
        static String name() {
            return "kam代付台账";
        }
    }
    public interface ReturnMoneyRecordViewWeb {
        static String code() {
            return "returnMoneyRecordViewWeb";
        }
        static String name() {
            return "履历台账";
        }
    }
}
